# Código de Conducta del Pacto de Colaboradores

## Nuestro Compromiso

Nosotros, como miembros, colaboradores y líderes, nos comprometemos a hacer que la participación en nuestra
comunidad sea una experiencia libre de acoso para todos, independientemente de la edad, tamaño corporal,
discapacidad visible o invisible, etnia, características sexuales, identidad y expresión de género,
nivel de experiencia, educación, estatus socioeconómico, nacionalidad, apariencia personal, raza, religión, o identidad y orientación sexual.

Nos comprometemos a actuar e interactuar de maneras que contribuyan a una comunidad abierta, acogedora,
diversa, inclusiva y saludable.

## Nuestros estándares

Ejemplos de comportamiento que contribuyen a un entorno positivo para nuestra
comunidad incluyen:

* Demostrar empatía y amabilidad hacia otras personas
* Ser respetuoso con opiniones, puntos de vista y experiencias diferentes
* Dar y aceptar con elegancia comentarios constructivos
* Aceptar la responsabilidad y disculparse con aquellos afectados por nuestros errores,
  y aprender de la experiencia
* Centrarse en lo que es mejor no solo para nosotros como individuos, sino para
  la comunidad en general

Ejemplos de comportamientos inaceptables incluyen:

* El uso de lenguaje o imágenes sexualizadas, y atención o avances sexuales de cualquier tipo
* Comentarios provocadores, insultantes o despectivos, y ataques personales o políticos
* Acoso público o privado
* Publicar información privada de otros, como una dirección física o de correo electrónico, sin su permiso explícito
* Otro comportamiento que razonablemente pueda considerarse inapropiado en un entorno profesional

## Responsabilidades de Cumplimiento

Los líderes de la comunidad son responsables de aclarar y hacer cumplir nuestros estándares de
comportamiento aceptable y tomarán medidas correctivas apropiadas y justas en
respuesta a cualquier comportamiento que consideren inapropiado, amenazante, ofensivo,
o dañino.

Los líderes de la comunidad tienen el derecho y la responsabilidad de eliminar, editar o rechazar
comentarios, commits, código, ediciones de wiki, issues y otras contribuciones que no estén
alineadas con este Código de Conducta, y comunicarán las razones de las decisiones
de moderación cuando sea apropiado.

## Alcance

Este Código de Conducta aplica dentro de todos los espacios de la comunidad, y también aplica cuando
un individuo representa oficialmente a la comunidad en espacios públicos.
Ejemplos de representar a nuestra comunidad incluyen usar una dirección de correo electrónico oficial,
publicar a través de una cuenta oficial de redes sociales, o actuar como un
representante designado en un evento en línea o fuera de línea.

## Aplicación

Los casos de comportamiento abusivo, acosador o inaceptable pueden ser
reportados a los líderes de la comunidad responsables de la aplicación en
aw@funstory.ai.
Todas las quejas serán revisadas e investigadas de manera rápida y justa.

Todos los líderes de la comunidad están obligados a respetar la privacidad y seguridad del
denunciante de cualquier incidente.

## Directrices de aplicación

Los líderes de la comunidad seguirán estas Directrices de Impacto en la Comunidad para determinar
las consecuencias de cualquier acción que consideren una violación de este Código de Conducta:

### 1. Corrección

**Impacto en la comunidad**: Uso de lenguaje inapropiado u otro comportamiento considerado
poco profesional o no deseado en la comunidad.

**Consecuencia**: Una advertencia privada y escrita por parte de los líderes de la comunidad, proporcionando
claridad sobre la naturaleza de la violación y una explicación de por qué el
comportamiento fue inapropiado. Se puede solicitar una disculpa pública.

### 2. Advertencia

**Impacto en la Comunidad**: Una violación a través de un incidente único o una serie
de acciones.

**Consecuencia**: Una advertencia con consecuencias por comportamiento continuado. Sin
interacción con las personas involucradas, incluyendo interacción no solicitada con
aquellos que hacen cumplir el Código de Conducta, por un período de tiempo especificado. Esto
incluye evitar interacciones en espacios de la comunidad así como en canales externos
como redes sociales. Violar estos términos puede llevar a una prohibición temporal o
permanente.

### 3. Prohibición temporal

**Impacto en la comunidad**: Una violación grave de los estándares de la comunidad, incluyendo
comportamiento inapropiado sostenido.

**Consecuencia**: Una prohibición temporal de cualquier tipo de interacción o comunicación
pública con la comunidad por un período de tiempo especificado. No se permite
ninguna interacción pública o privada con las personas involucradas, incluyendo
interacción no solicitada con aquellos que hacen cumplir el Código de Conducta,
durante este período. Violar estos términos puede llevar a una prohibición permanente.

### 4. Prohibición permanente

**Impacto en la comunidad**: Demostrar un patrón de violación de los estándares de la comunidad, incluyendo comportamiento inapropiado sostenido, acoso a un individuo, o agresión o menosprecio hacia clases de individuos.

**Consecuencia**: Una prohibición permanente de cualquier tipo de interacción pública dentro de la comunidad.

## Atribución

Este Código de Conducta está adaptado del [Contributor Covenant][homepage],
versión 2.0, disponible en
https://www.contributor-covenant.org/version/2/0/code_of_conduct.html.

Las Directrices de Impacto en la Comunidad se inspiraron en [el escalafón de aplicación del código de conducta de Mozilla](https://github.com/mozilla/diversity).

[homepage]: https://www.contributor-covenant.org

Para respuestas a preguntas comunes sobre este código de conducta, consulte las Preguntas frecuentes en
https://www.contributor-covenant.org/faq. Las traducciones están disponibles en
https://www.contributor-covenant.org/translations.

<div align="right"> 
<h6><small>Parte del contenido de esta página ha sido traducido por GPT y puede contener errores.</small></h6>